pub struct Matching { /* private fields */ }Expand description
Returns true if the given variable is a string and matches the regex in the pat argument.
The regex will only be compiled once.
{% if value is matching(pat="^hello") %}...{% endif %}Trait Implementations